@@ -171,7 +171,11 @@ class FaasJobManager(metaclass=Singleton):
                 ):
                     _end_job(job_data)
 
-                    if self.process_id is not None and process_data is None and trace_states:
+                    if (
+                        self.process_id is not None
+                        and process_data is None
+                        and trace_states
+                    ):
                         process_data = self.datastore.get_entity(
                             self.process_entity, self.process_id
                         )
@@ -182,6 +186,16 @@ class FaasJobManager(metaclass=Singleton):
                         )
                         _multi_data.append(process_data)
 
+                if job_data["tasks_info"].get(str(self.ref_pow)) is None:
+                    task_info = FaasTaskState(
+                        state=FaasOpState.CRTD,
+                        parent_ref=req.task_parent_ref,
+                        name=task_name,
+                    )
+                    job_data["tasks_info"][str(self.ref_pow)] = Entity(
+                        exclude_from_indexes=tuple(task_info.keys())
+                    )
+                    job_data["tasks_info"][str(self.ref_pow)].update(asdict(task_info))
                 job_data["tasks_info"][str(self.ref_pow)]["state"] = _task_state.name
 
                 _multi_data.append(job_data)
